==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fRet__5fw.h <==
// class soot.coffi.Instruction_Ret_w

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 23a8d749d607a556 soot_coffi_Instruction__5fRet__5fw
// @dep_class ab4b7552e3da85b4 soot_coffi_Instruction__5fintvar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintvar

#include "soot/coffi/Instruction__5fintvar.h"

#ifndef _JC_soot_coffi_Instruction__5fRet__5fw_H_
#define _JC_soot_coffi_Instruction__5fRet__5fw_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_refs	_jc_soot_coffi_Instruction__5fRet__5fw$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs	_jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$refs	_jc_soot_coffi_Instruction__5fRet__5fw$refs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$nonrefs	_jc_soot_coffi_Instruction__5fRet__5fw$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$object	_jc_soot_coffi_Instruction__5fRet__5fw$object;

typedef const struct _jc_soot_coffi_Instruction__5fRet__5fw$vmethods	_jc_soot_coffi_Instruction__5fRet__5fw$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fRet__5fw$vtable	_jc_soot_coffi_Instruction__5fRet__5fw$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fRet__5fw$vtype	_jc_soot_coffi_Instruction__5fRet__5fw$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fRet__5fw$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fRet__5fw$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fRet__5fw$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fRet__5fw$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintvar$vmethods	soot_coffi_Instruction__5fintvar;
	_jc_soot_coffi_Instruction__5fRet__5fw$vmethods	soot_coffi_Instruction__5fRet__5fw;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fRet__5fw$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fRet__5fw$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet__5fw$refs {
    _jc_soot_coffi_Instruction__5fRet__5fw$sub_refs	soot_coffi_Instruction__5fRet__5fw;
    _jc_soot_coffi_Instruction__5fintvar$sub_refs	soot_coffi_Instruction__5fintvar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet__5fw$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintvar$sub_nonrefs	soot_coffi_Instruction__5fintvar;
    _jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs	soot_coffi_Instruction__5fRet__5fw;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fRet__5fw$object {
	_jc_soot_coffi_Instruction__5fRet__5fw$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fRet__5fw$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fRet__5fw$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fRet__5fw$vtype _jc_soot_coffi_Instruction__5fRet__5fw$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fRet__5fw, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fRet__5fw$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fRet__5fw_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fRet__5fw.h <==
// class soot.coffi.Instruction_Ret_w

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 23a8d749d607a556 soot_coffi_Instruction__5fRet__5fw
// @dep_class ab4b7552e3da85b4 soot_coffi_Instruction__5fintvar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintvar

#include "soot/coffi/Instruction__5fintvar.h"

#ifndef _JC_soot_coffi_Instruction__5fRet__5fw_H_
#define _JC_soot_coffi_Instruction__5fRet__5fw_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_refs	_jc_soot_coffi_Instruction__5fRet__5fw$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs	_jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$refs	_jc_soot_coffi_Instruction__5fRet__5fw$refs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$nonrefs	_jc_soot_coffi_Instruction__5fRet__5fw$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet__5fw$object	_jc_soot_coffi_Instruction__5fRet__5fw$object;

typedef const struct _jc_soot_coffi_Instruction__5fRet__5fw$vmethods	_jc_soot_coffi_Instruction__5fRet__5fw$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fRet__5fw$vtable	_jc_soot_coffi_Instruction__5fRet__5fw$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fRet__5fw$vtype	_jc_soot_coffi_Instruction__5fRet__5fw$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fRet__5fw$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fRet__5fw$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fRet__5fw$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fRet__5fw$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintvar$vmethods	soot_coffi_Instruction__5fintvar;
	_jc_soot_coffi_Instruction__5fRet__5fw$vmethods	soot_coffi_Instruction__5fRet__5fw;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fRet__5fw$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fRet__5fw$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet__5fw$refs {
    _jc_soot_coffi_Instruction__5fRet__5fw$sub_refs	soot_coffi_Instruction__5fRet__5fw;
    _jc_soot_coffi_Instruction__5fintvar$sub_refs	soot_coffi_Instruction__5fintvar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet__5fw$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintvar$sub_nonrefs	soot_coffi_Instruction__5fintvar;
    _jc_soot_coffi_Instruction__5fRet__5fw$sub_nonrefs	soot_coffi_Instruction__5fRet__5fw;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fRet__5fw$object {
	_jc_soot_coffi_Instruction__5fRet__5fw$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fRet__5fw$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fRet__5fw$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fRet__5fw$vtype _jc_soot_coffi_Instruction__5fRet__5fw$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fRet__5fw, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fRet__5fw$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fRet__5fw_H_ */
